/*************************************************************************\
* Copyright (c) 2002 The University of Chicago, as Operator of Argonne
* National Laboratory.
* Copyright (c) 2002 The Regents of the University of California, as
* Operator of Los Alamos National Laboratory.
* This file is distributed subject to a Software License Agreement found
* in the file LICENSE that is included with this distribution. 
\*************************************************************************/
/*
 * DBR.java,v 1.2 2002/08/02 15:39:13 jba Exp
 */

package jca.dbr;
import java.lang.*;

/**
 * The DBR (DataBase Request) interface. It represents the base interface for all DBR requests.
 * A DBR is used to send or receive a piece of information from/to a Channel Access server.
 *
 * This API is very likely to change in the futur.
 *
 */
public interface DBR {
  /**
   * A DBR type. Represents the DBR_STRING type.
   *
   * @see jca.dbr.DBR_DBString
   */
  public static final int STRING            =0;
  /** 
   * A DBR type. Represents the DBR_SHORT type.
   *
   * @see jca.dbr.DBR_DBShort
   */
  public static final int	SHORT             =1;
  /** 
   * A DBR type. Represents the DBR_FLOAT type.
   *
   * @see jca.dbr.DBR_DBFloat
   */
  public static final int	FLOAT             =2;
  /** 
   * A DBR type. Represents the DBR_ENUM type.
   *
   * @see jca.dbr.DBR_DBEnum
   */
  public static final int	ENUM              =3;
  /** 
   * A DBR type. Represents the DBR_CHAR type.
   *
   * @see jca.dbr.DBR_DBByte
   */
  public static final int	BYTE              =4;
  /** 
   * A DBR type. Represents the DBR_LONG type.
   *
   * @see jca.dbr.DBR_DBInt
   */
  public static final int	INT              =5;
  /** 
   * A DBR type. Represents the DBR_DOUBLE type.
   *
   * @see jca.dbr.DBR_DBDouble
   */
  public static final int	DOUBLE            =6;
  /** 
   * A DBR type. Represents the DBR_STS_STRING type.
   *
   * @see jca.dbr.DBR_STS
   * @see jca.dbr.DBR_STS_DBString
   */
  public static final int	STS_STRING        =7;
  /** 
   * A DBR type. Represents the DBR_STS_SHORT type.
   *
   * @see jca.dbr.DBR_STS
   * @see jca.dbr.DBR_STS_DBShort
   */
  public static final int	STS_SHORT         =8;
  /** 
   * A DBR type. Represents the DBR_STS_FLOAT type.
   *
   * @see jca.dbr.DBR_STS
   * @see jca.dbr.DBR_STS_DBFloat
   */
  public static final int	STS_FLOAT         =9;
  /** 
   * A DBR type. Represents the DBR_STS_ENUM type.
   *
   * @see jca.dbr.DBR_STS
   * @see jca.dbr.DBR_STS_DBEnum
   */
  public static final int	STS_ENUM          =10;
  /** 
   * A DBR type. Represents the DBR_STS_CHAR type.
   *
   * @see jca.dbr.DBR_STS
   * @see jca.dbr.DBR_STS_DBByte
   */
  public static final int	STS_BYTE          =11;
  /** 
   * A DBR type. Represents the DBR_STS_LONG type.
   *
   * @see jca.dbr.DBR_STS
   * @see jca.dbr.DBR_STS_DBInt
   */
  public static final int	STS_INT          =12;
  /** 
   * A DBR type. Represents the DBR_STS_DOUBLE type.
   *
   * @see jca.dbr.DBR_STS
   * @see jca.dbr.DBR_STS_DBDouble
   */
  public static final int	STS_DOUBLE        =13;
  /** 
   * A DBR type. Represents the DBR_TIME_STRING type.
   *
   * @see jca.dbr.DBR_TIME
   * @see jca.dbr.DBR_TIME_DBString
   */
  public static final int	TIME_STRING       =14;
  /** 
   * A DBR type. Represents the DBR_TIME_SHORT type.
   *
   * @see jca.dbr.DBR_TIME
   * @see jca.dbr.DBR_TIME_DBShort
   */
  public static final int	TIME_SHORT        =15;
  /** 
   * A DBR type. Represents the DBR_TIME_FLOAT type.
   *
   * @see jca.dbr.DBR_TIME
   * @see jca.dbr.DBR_TIME_DBFloat
   */
  public static final int	TIME_FLOAT        =16;
  /** 
   * A DBR type. Represents the DBR_TIME_ENUM type.
   *
   * @see jca.dbr.DBR_TIME
   * @see jca.dbr.DBR_TIME_DBEnum
   */
  public static final int	TIME_ENUM         =17;
  /** 
   * A DBR type. Represents the DBR_TIME_CHAR type.
   *
   * @see jca.dbr.DBR_TIME
   * @see jca.dbr.DBR_TIME_DBByte
   */
  public static final int	TIME_BYTE         =18;
  /** 
   * A DBR type. Represents the DBR_TIME_LONG type.
   *
   * @see jca.dbr.DBR_TIME
   * @see jca.dbr.DBR_TIME_DBInt
   */
  public static final int	TIME_INT         =19;
  /** 
   * A DBR type. Represents the DBR_DOUBLE type.
   *
   * @see jca.dbr.DBR_TIME
   * @see jca.dbr.DBR_TIME_DBDouble
   */
  public static final int	TIME_DOUBLE       =20;

  /** 
   * A DBR type. Represents the DBR_GR_SHORT type.
   *
   * @see jca.dbr.DBR_GR
   * @see jca.dbr.DBR_GR_DBShort
   */
  public static final int	GR_SHORT          =22;
  /** 
   * A DBR type. Represents the DBR_GR_FLOAT type.
   *
   * @see jca.dbr.DBR_GR
   * @see jca.dbr.DBR_GR_DBFloat
   */
  public static final int	GR_FLOAT          =23;
  /** 
   * A DBR type. Represents the DBR_GR_ENUM type.
   *
   * @see jca.dbr.DBR_INFO_DBEnum
   */
  public static final int	INFO_ENUM         =24;
  /** 
   * A DBR type. Represents the DBR_GR_CHAR type.
   *
   * @see jca.dbr.DBR_INFO_DBByte
   */
  public static final int	GR_BYTE           =25;
  /** 
   * A DBR type. Represents the DBR_GR_LONG type.
   *
   * @see jca.dbr.DBR_GR
   * @see jca.dbr.DBR_GR_DBInt
   */
  public static final int	GR_INT           =26;
  /** 
   * A DBR type. Represents the DBR_GR_DOUBLE type.
   *
   * @see jca.dbr.DBR_GR
   * @see jca.dbr.DBR_GR_DBDouble
   */
  public static final int	GR_DOUBLE         =27;
  /** 
   * A DBR type. Represents the DBR_CTRL_SHORT type.
   *
   * @see jca.dbr.DBR_CTRL
   * @see jca.dbr.DBR_CTRL_DBShort
   */
  public static final int	CTRL_SHORT        =29;
  /** 
   * A DBR type. Represents the DBR_CTRL_FLOAT type.
   *
   * @see jca.dbr.DBR_CTRL
   * @see jca.dbr.DBR_CTRL_DBFloat
   */
  public static final int	CTRL_FLOAT        =30;
  /** 
   * A DBR type. Represents the DBR_CTRL_CHAR type.
   *
   * @see jca.dbr.DBR_CTRL
   * @see jca.dbr.DBR_CTRL_DBByte
   */
  public static final int	CTRL_BYTE         =32;
  /** 
   * A DBR type. Represents the DBR_CTRL_LONG type.
   *
   * @see jca.dbr.DBR_CTRL
   * @see jca.dbr.DBR_CTRL_DBInt
   */
  public static final int	CTRL_INT         =33;
  /** 
   * A DBR type. Represents the DBR_CTRL_DOUBLE type.
   *
   * @see jca.dbr.DBR_CTRL
   * @see jca.dbr.DBR_CTRL_DBDouble
   */
  public static final int	CTRL_DOUBLE       =34;
  /** 
   * A DBR type. Represents the DBR_PUT_ACKT type.
   *
   * @see jca.dbr.DBR_PUT_ACKT
   */
  public static final int	PUT_ACKT          =35;
  /** 
   * A DBR type. Represents the DBR_PUT_ACKS type.
   *
   * @see jca.dbr.DBR_PUT_ACKS
   */
  public static final int	PUT_ACKS          =36;
  /** 
   * A DBR type. Represents the DBR_STSACK_STRING type.
   *
   * @see jca.dbr.DBR_STSACK_DBString
   */
  public static final int	STSACK_STRING     =37;


  /**
   * Return the DBR type of the object.
   */
  public int type();

  /**
   * Return the DBR count of the object.
   */
  public int count();


  public DBData dataAt(int at);
  
//   /**
//    * Return the first element of this DBR.
//    */
//   public synchronized DBData getFirstElement();

//   /**
//    * Return the element at a specific index of this DBR.
//    *
//    * @param index the index of the element to be returned.
//    */
//   public synchronized DBData getElementAt(int index);

//   /**
//    * Return the last element of this DBR.
//    */
//   public synchronized DBData getLastElement();

//   /**
//    * Return a DBData array of all the elements.
//    */
//   public synchronized DBData[] toArray();

//   /**
//    * Copy the elements of this DBR into a destination array. 
//    * The array object must be of the same underlying DBR's data type.
//    * <p>
//    * If the underlying data type is a primitive type, dest must be an array of this type.
//    * <p>
//    * If the underlying data type is a String, dest must be an array of String. 
//    * Since array of String are not supported yet by Channel Access, the array length should be 1.
//    * <p>
//    * <p>
//    * If dest is null, a NullPointerException is thrown. 
//    * <p>
//    * If dest is not of the same underlying data type, a ArrayStoreException is thrown.
//    *
//    *
//    * @param dest The array object into which the elements will be copied.
//    */
//   public synchronized void copyTo(Object dest);
}
