/*************************************************************************\
* Copyright (c) 2002 The University of Chicago, as Operator of Argonne
* National Laboratory.
* Copyright (c) 2002 The Regents of the University of California, as
* Operator of Los Alamos National Laboratory.
* This file is distributed subject to a Software License Agreement found
* in the file LICENSE that is included with this distribution. 
\*************************************************************************/
/*
 * DBR_CTRL_DBShort.java,v 1.2 2002/08/02 15:39:14 jba Exp
 */

package jca.dbr;
import java.lang.*;

/**
 * This class represents the Channel Access DBR_CTRL_SHORT type.
 *
 */
public class DBR_CTRL_DBShort extends DBR_GR_DBShort implements DBR_CTRL {
  private short   m_upper_ctrl_limit;
  private short   m_lower_ctrl_limit;

  /**
   * Create a new DBR_CTRL_DBShort object to hold 1 value.
   */
  public DBR_CTRL_DBShort() {
    super(1);
  }
  
  /**
   * Create a new DBR_CTRL_DBShort object to hold count value.
   *
   * @param count the number of values to be held by this object.
   */
  public DBR_CTRL_DBShort(int count) {
    super(count);
  }

  /**
   * Return the Channel Access request type.
   */
  public int type() {
    return DBR.CTRL_SHORT;
  }

  /**
   * Return the upper control limit.
   */
  public DBData upperCtrlLimit() {
    return new DBShort(m_upper_ctrl_limit);
  }

  /** 
   * Return the lower control limit.
   */
  public DBData lowerCtrlLimit() {
    return new DBShort(m_lower_ctrl_limit);
  }

  protected void setInfo(short status, short severity,
                      String units,
                      short upper_disp_limit,
                      short lower_disp_limit,
                      short upper_alarm_limit,
                      short upper_warning_limit,
                      short lower_warning_limit,
                      short lower_alarm_limit,
                      short upper_ctrl_limit,
                      short lower_ctrl_limit) {
    super.setInfo(status,severity,
                  units,
                  upper_disp_limit,
                  lower_disp_limit,
                  upper_alarm_limit,
                  upper_warning_limit,
                  lower_warning_limit,
                  lower_alarm_limit);
    m_upper_ctrl_limit= upper_ctrl_limit;
    m_lower_ctrl_limit= lower_ctrl_limit;
  };                      
}
